<template lang="pug">
div
    transition(name="fade" mode="in-out")
        app-initial-loading(v-if="isLoading" key="1")
    template(v-if="!isLoading")
        AppHeader
        nuxt.app-layout(:class="generateClass")
</template>

<script>
import { mapActions, mapMutations, mapGetters } from 'vuex'
import AppHeader from '@/components/layout/Header'
import AppInitialLoading from '@/components/atoms/AppInitialLoading'
export default {
    components: {
        AppHeader,
        AppInitialLoading,
    },
    data: () => ({
        isLoading: true,
    }),
    async created() {
        this.setQueryLinkMutation(this.$route.query.track)
        await this.fetchCurrentRoute()
    },
    computed: {
        ...mapGetters({
            currentRoute: 'currentRoute',
        }),
    },
    methods: {
        ...mapMutations([
            'setQueryLinkMutation',
            'setSelectedRouteMutation',
        ]),
        ...mapActions({
            getCurrentRoute: 'getCurrentRoute',
            getSpecialOrder: 'getSpecialOrder'
        }),
        async fetchCurrentRoute() {
            try {
                let route = this.$route.query
                if(route?.type == 'signature'){
                   await this.getSpecialOrder()
                }else{
                    const response = await this.getCurrentRoute()
                    if (response.data.mode !== 1) {
                        this.setSelectedRouteMutation(response.data.data[0])
                    }
                }
            } catch (error) {
                if (error.response) {
                    return this.$nuxt.error({
                        statusCode: error.response.status,
                        message: error.response.data.message,
                    })
                }
            } finally {
                this.isLoading = false
            }
        },
        generateClass(){
            if(this.$route.query?.type == 'signature') return 'app-layout--scroll'
            return this.currentRoute.mode === 1 ? 'app-layout--scroll' : ''
        }
    },
}
</script>
